virlsdk — virlsdk 0.1.post0.dev1+ng910c7a3.dirty documentation

# virlsdk

This is the documentation of virlsdk.

Note

This is the main page of your project’s Sphinx documentation. It is formatted in reStructuredText. Add additional pages by creating rst-files in `docs` and adding them to the toctree below. Use then references in order to link them from this page, e.g. authors and Changelog.

It is also possible to refer to the documentation of other Python packages with the Python domain syntax. By default you can reference the documentation of Sphinx, Python, NumPy, SciPy, matplotlib, Pandas, Scikit-Learn. You can add more by extending the `intersphinx_mapping` in your Sphinx’s `conf.py`.

The pretty useful extension autodoc is activated by default and lets you include documentation from docstrings. Docstrings can be written in Google (recommended!), NumPy and classical style.

## Contents

- License
- Authors
- Changelog
  - Version 0.1
- Module Reference

## Indices and tables

- Index
- Module Index
- Search Page